/********************************************************
 *  SKOLSKY ZVONCEK
 *=======================================================
 * Author  : Ing. Miroslav Tesar                  
 * Platform: Arduino NANO 328P
 * Version : 1.00
 * Date    : 03.12.2019
 * e-mail  : tesar@imt.eu.sk
 * ======================================================
 * STRUKTURY, PREMENNE A INSTANCIE
 ********************************************************/

/********************************************************
 * DEKLARACIA STRUKTURY PREMENNYC
 ********************************************************/
 typedef struct  {
   bool ExistenciaSuboru     : 1;
   bool PriznakMinuta        : 1; // Priznak sekundy pre Casomieru
   bool PriznakPolnoc        : 1; // Priznak polnoci
   bool Tik                  : 1;
   bool PriznakBlik          : 1; // Priznak pre blikanie
   bool PriznakRTC           : 1; // Priznak hodin od RTC
   bool PriznakOE            : 1; // Priznak tlacidla OE
   bool PriznakMinuty        : 1; // Priznak, ze sa zmenila minuta
   bool PriznakTlacidla      : 1; // Priznak, ze bolo stacene tlacidlo
   bool ZmenaPostfixu        : 1; // Zmena postfixu
   bool ZmenaCasu            : 1; // Zmena casu
   bool PriznakTik           : 1; // Priznak polsekundy
   bool PriznakKoniec        : 1; // Priznak konca suboru
   bool Mod                  : 1; // 0.. koniec nastavovani casu
                                  // 1.. nastav cas                             
   byte PriznakNastavCas;         // 0 - nenastavuj
                                  // 1 - rezim nastav hodiny
                                  // 2 - rezim nastav minuty
                                  // 3 - rezim nastav den
                                  // 4 - rezim nastav mesiac
   byte PamatMinuty          = 0; // Minuta z predchadzajuceho citania
   byte Chyba                = 0; // Cislo chyby
   unsigned int DelickaCas   = 0; // Cas tvoriaci 1 sec
   unsigned int DelickaTik   = 0; // Cas tvoriaci pol sekundy
   unsigned long DelickaBlik = 0; // Cas tvoriaci 1/4 sec                
 } typPremenna;

/********************************************************
 * DEKLARACIA STRUKTURY SD KARTY - PORADIE ZAZNAMU DAT
 ********************************************************/
 typedef struct  {
   char H10;  // Desiatky hodin casu zvonenie
   char H01;  // Jednotky hodin casu zvonenie
   char M10;  // Desiatky minut casu zvonenie
   char M01;  // Jednotky minut casu zvonenie
   char Sec;  // Cas zvonenia v sekundach
   char Po ;  // Priznak zvonenia v pondelok
   char Ut ;  // Priznak zvonenia v utorok
   char St ;  // Priznak zvonenia v stredu
   char Sv ;  // Priznak zvonenia vo stvrtok
   char Pi ;  // Priznak zvonenia v piatok
   char So ;  // Priznak zvonenia v sobotu
   char Ne ;  // Priznak zvonenia v nedelu
   char Odd;  // Oddelovacie znaky : Tab Cr LF
 } typSDcard;
 
/********************************************************
 * DEKLARACIA STRUKTURY SD KARTY V CISELNEJ A BINARNEJ PODOBE
 ********************************************************/
 typedef struct  {
   int  PocetMinut    ; // Vypocitane minuty z casu HH:SS
   int  ZvoncekSekundy; // Vypocitane sekundy pre zvonenie
   bool Pondelok   : 1; // Binarna hodnota priznaku zvonenia
   bool Utorok     : 1; // Binarna hodnota priznaku zvonenia
   bool Streda     : 1; // Binarna hodnota priznaku zvonenia
   bool Stvrtok    : 1; // Binarna hodnota priznaku zvonenia
   bool Piatok     : 1; // Binarna hodnota priznaku zvonenia
   bool Sobota     : 1; // Binarna hodnota priznaku zvonenia
   bool Nedela     : 1; // Binarna hodnota priznaku zvonenia
 } typSDHodnota;

/*******************************************************
 * STRUKTURA Display_STRUCT
 *******************************************************/
 typedef struct {
   byte Minuty;     // Ciselna podoba minut    0..60
   byte Hodiny;     // Ciselna podoba hodin    0..24
   byte PozDne;     // Pozicia dne v tyzdni    1.. 7
   byte Postfix;    // Pouzity postfix suboru
   int  PocetMinut; // Cas vyjadreny v minutach
 } typCas;
  
/*******************************************************
 * STRUKTURA Display_595
 *******************************************************/
 union Cas_Struct {
   struct {
     byte PozDne;   // Pozicia dne v tyzdni
     byte Postfix;  // Ciselna podoba cisla suboru
     byte Min01;    // Ciselna podoba jednotiek minut
     byte Min10;    // Ciselna podoba desiatok  minut
     byte Hod01;    // Ciselna podoba jednotiek hodin
     byte Hod10;    // Ciselna podoba desiatok  hodin
   };
     byte Fronta[DlzkaFronty];
 };

/********************************************************
 * DEKLARACIA PREMENNYCH
 ********************************************************/
 String PrefixSuboru  = "Zvoncek";
 String PostfixSuboru = ""; 
 String PriponaSuboru = ".txt";
 String Subor         = "";

 byte AdresaEEPROM    = 0x00;
 byte FillFronta[DlzkaFronty];

 typPremenna  Premenna;     // Pomocne premenne
 typSDcard    SDcard;       // SD karta
 typSDHodnota SDHodnota;    // SD karta
 typCas       DisplejCas;   // Displej
 Cas_Struct   Cas_HC595;    // Displej

/********************************************************
 * INSTANCIE
 ********************************************************/
 Sd2Card  card;
 SdVolume volume;
 SdFile   root;

 File Zaznam;
 
