/********************************************************
 *  SKOLSKY ZVONCEK
 *=======================================================
 * Author  : Ing. Miroslav Tesar                  
 * Platform: Arduino NANO 328P
 * Version : 1.00
 * Date    : 03.12.2019
 * e-mail  : tesar@imt.eu.sk
 * ======================================================
 * INICIALIZACIE
 ********************************************************/
   
/*******************************************************
 * SAVE FRONTA
 * -----------------------------------------------------
 * Fyzicke odoslanie dat do obvodov 74HCT595
 * Odosielaju sa informacie o teplota/RTC/Casomiera
 * podle rezimu cinnosti tabule.
 * Parameter *pole ziskava adresu prvej zlozky Fronta
 * a pomocou shiftout posiela data z adries Fronta
 *******************************************************/
 void saveFronta(byte *pole) {
                
   for (byte i=0;i<DlzkaFronty;i++) {
     shiftOut(pin_Data,pin_Clock,LSBFIRST,*(pole+i));
   }
   digitalWrite(pin_Latch,HIGH); // Prepis do displejov po
   digitalWrite(pin_Latch,LOW ); // zapisu celej fronty
 }

/******************************************************** 
 *  INICIALIZACIA SD CARD
 ********************************************************/
 void InitSD() {
   if (SD.begin(pinCS)) {
     Premenna.Chyba = BezChyby;     
   }
   else {
     Cas_HC595.PozDne  = ZnakBlank;
     Cas_HC595.Postfix = ZnakBlank;
     Cas_HC595.Min01   = Znak1;
     Cas_HC595.Min10   = Znak0;
     Cas_HC595.Hod01   = Znakr;
     Cas_HC595.Hod10   = ZnakE;
     saveFronta(&Cas_HC595.Fronta[0]);  // (20)
   }
 }

/******************************************************** 
 *  INICIALIZACIA EEPROM
 ********************************************************/
 void KonvertujPostfix() {
   switch (DisplejCas.Postfix) {
     case 0  : PostfixSuboru = "0"; break;
     case 1  : PostfixSuboru = "1"; break;
     case 2  : PostfixSuboru = "2"; break;
     case 3  : PostfixSuboru = "3"; break;
     case 4  : PostfixSuboru = "4"; break;
     case 5  : PostfixSuboru = "5"; break;
     case 6  : PostfixSuboru = "6"; break;
     case 7  : PostfixSuboru = "7"; break;
     case 8  : PostfixSuboru = "8"; break;
     case 9  : PostfixSuboru = "9"; break;
     default : PostfixSuboru = "0";
   }  
 }

/******************************************************** 
 *  INICIALIZACIA EEPROM
 ********************************************************/
 void InitEEPROM() {
   DisplejCas.Postfix = EEPROM.read(AdresaEEPROM);

   if (DisplejCas.Postfix == 255) {
     DisplejCas.Postfix = MinPostfix;
     EEPROM.write(AdresaEEPROM,DisplejCas.Postfix);
   }
   
   KonvertujPostfix();      // (20)
 } 

/******************************************************** 
 *  INICIALIZACIA SUBORU
 ********************************************************/
 void InitSubor() {
   Subor = PrefixSuboru + PostfixSuboru + PriponaSuboru;

   Premenna.ExistenciaSuboru = SD.exists(Subor);
   if (Premenna.ExistenciaSuboru) {
     Premenna.Chyba = BezChyby;
   } 
   else {
     Cas_HC595.PozDne  = ZnakBlank;
     switch (DisplejCas.Postfix) {
       case 0 : Cas_HC595.Postfix = Znak0; break;
       case 1 : Cas_HC595.Postfix = Znak1; break;
       case 2 : Cas_HC595.Postfix = Znak2; break;
       case 3 : Cas_HC595.Postfix = Znak3; break;
       case 4 : Cas_HC595.Postfix = Znak4; break;
       case 5 : Cas_HC595.Postfix = Znak5; break;
       case 6 : Cas_HC595.Postfix = Znak6; break;
       case 7 : Cas_HC595.Postfix = Znak7; break;
       case 8 : Cas_HC595.Postfix = Znak8; break;
       case 9 : Cas_HC595.Postfix = Znak9; break;
     }
     Cas_HC595.Min01   = Znak2;
     Cas_HC595.Min10   = Znak0;
     Cas_HC595.Hod01   = Znakr;
     Cas_HC595.Hod10   = ZnakE;
     saveFronta(&Cas_HC595.Fronta[0]);  // (20)
   } 
 }

/********************************************************
 * Otvor subor
 ********************************************************/
 OtvorSubor() {
   if (Premenna.ExistenciaSuboru) { 
     Zaznam = SD.open(Subor);
     Premenna.Chyba = BezChyby;
   }
   else { 
     Cas_HC595.PozDne  = ZnakBlank;
     switch (DisplejCas.Postfix) {
       case 0 : Cas_HC595.Postfix = Znak0; break;
       case 1 : Cas_HC595.Postfix = Znak1; break;
       case 2 : Cas_HC595.Postfix = Znak2; break;
       case 3 : Cas_HC595.Postfix = Znak3; break;
       case 4 : Cas_HC595.Postfix = Znak4; break;
       case 5 : Cas_HC595.Postfix = Znak5; break;
       case 6 : Cas_HC595.Postfix = Znak6; break;
       case 7 : Cas_HC595.Postfix = Znak7; break;
       case 8 : Cas_HC595.Postfix = Znak8; break;
       case 9 : Cas_HC595.Postfix = Znak9; break;
     }
     Cas_HC595.Min01   = Znak3;
     Cas_HC595.Min10   = Znak0;
     Cas_HC595.Hod01   = Znakr;
     Cas_HC595.Hod10   = ZnakE;
     saveFronta(&Cas_HC595.Fronta[0]);  // (20)
   }
 }

/********************************************************
 * CITAJ RIADOK
 ********************************************************/
 Konverzia() {  
   SDHodnota.ZvoncekSekundy = ((SDcard.Sec-48)*1000);
    
   if(SDcard.Po == '1') SDHodnota.Pondelok = true;
   else                 SDHodnota.Pondelok = false;
   
   if(SDcard.Ut == '1') SDHodnota.Utorok   = true;
   else                 SDHodnota.Utorok   = false;
   
   if(SDcard.St == '1') SDHodnota.Streda   = true;
   else                 SDHodnota.Streda   = false;
   
   if(SDcard.Sv == '1') SDHodnota.Stvrtok  = true;
   else                 SDHodnota.Stvrtok  = false;
   
   if(SDcard.Pi == '1') SDHodnota.Piatok   = true;
   else                 SDHodnota.Piatok   = false;
   
   if(SDcard.So == '1') SDHodnota.Sobota   = true;
   else                 SDHodnota.Sobota   = false;
   
   if(SDcard.Ne == '1') SDHodnota.Nedela   = true;
   else                 SDHodnota.Nedela   = false;
 }

/********************************************************
 * CITAJ RIADOK
 ********************************************************/
 CitajRiadok() {
   int _h10;
   int _h01;
   int _m10;
   int _m01;
  
   if ((Zaznam.available()> 0) && (!Premenna.PriznakKoniec)) {
     SDcard.H10 = Zaznam.read();  Serial.print(SDcard.H10);
     SDcard.H01 = Zaznam.read();  Serial.print(SDcard.H01);
     SDcard.Odd = Zaznam.read();  Serial.print(SDcard.Odd);
     SDcard.M10 = Zaznam.read();  Serial.print(SDcard.M10);
     SDcard.M01 = Zaznam.read();  Serial.print(SDcard.M01);
     SDcard.Odd = Zaznam.read();  Serial.print(SDcard.Odd);
     SDcard.Sec = Zaznam.read();  Serial.print(SDcard.Sec);
     SDcard.Odd = Zaznam.read();  Serial.print(SDcard.Odd);
     SDcard.Po  = Zaznam.read();  Serial.print(SDcard.Po );
     SDcard.Odd = Zaznam.read();  Serial.print(SDcard.Odd);
     SDcard.Ut  = Zaznam.read();  Serial.print(SDcard.Ut );
     SDcard.Odd = Zaznam.read();  Serial.print(SDcard.Odd);
     SDcard.St  = Zaznam.read();  Serial.print(SDcard.St );
     SDcard.Odd = Zaznam.read();  Serial.print(SDcard.Odd);
     SDcard.Sv  = Zaznam.read();  Serial.print(SDcard.Sv );
     SDcard.Odd = Zaznam.read();  Serial.print(SDcard.Odd);
     SDcard.Pi  = Zaznam.read();  Serial.print(SDcard.Pi );
     SDcard.Odd = Zaznam.read();  Serial.print(SDcard.Odd);
     SDcard.So  = Zaznam.read();  Serial.print(SDcard.So );
     SDcard.Odd = Zaznam.read();  Serial.print(SDcard.Odd);
     SDcard.Ne  = Zaznam.read();  Serial.print(SDcard.Ne );

     _h10 = (SDcard.H10-48)*600;
     _h01 = (SDcard.H01-48)* 60; 
     _m10 = (SDcard.M10-48)* 10;
     _m01 = (SDcard.M01-48)*  1;
     SDHodnota.PocetMinut = _h10 + _h01 + _m10 + _m01;
     Serial.print(SDcard.Odd);
     Serial.print(SDHodnota.PocetMinut);
     
     SDcard.Odd = Zaznam.read();  Serial.print(SDcard.Odd);
     SDcard.Odd = Zaznam.read();  Serial.print(SDcard.Odd);

//     _h10 = (SDcard.H10-48)*600;
//     _h01 = (SDcard.H01-48)* 60; 
//     _m10 = (SDcard.M10-48)* 10;
//     _m01 = (SDcard.M01-48)*  1;
//     SDHodnota.PocetMinut = _h10 + _h01 + _m10 + _m01;

     Konverzia();    // (20)
   }
   else Premenna.PriznakKoniec = Ano;
 }

/******************************************************** 
 *  INICIALIZACIA PIN
 ********************************************************/
 void InitBlikanie() {
   for(byte i = 0; i < DlzkaFronty; i++) 
     FillFronta[i] = 0; // pre blikane TEST
 }
 
