/********************************************************
 * SKOLSKY ZVONCEK
 *=======================================================
 * Author  : Ing. Miroslav Tesar                  
 * Platform: Arduino NANO 328P
 * Version : 1.00
 * Date    : 03.12.2019
 * e-mail  : tesar@imt.eu.sk
 ********************************************************/

/********************************************************
 * KNIZNICE
 ********************************************************/
 #include <Wire.h>
 #include <SPI.h>
 #include <SD.h>
 #include <EEPROM.h>

 #include "Vrstva00.h" // Konstanty
 #include "Vrstva01.h" // Inicializacia pinov
 #include "Vrstva10.h" // SD karta
 #include "Vrstva20.h" // Displej
 #include "Vrstva30.h" // Konverzie
 #include "Vrstva40.h" // RTC
 #include "Vrstva50.h" // Zapis do displeja
 #include "Vrstva60.h" // Nastavovani RTC, Analyzy
 #include "Vrstva70.h" // Tlacidla
// #include "Vrstva90.h" // TEST - Nastav cas

/********************************************************
 * SETUP
 ********************************************************/
 void setup (void) {
   Serial.begin(9600);
   Wire.begin();
   
   attachInterrupt(INT0,RTC32K,RISING); // pin 2 

   InitPin();                           // (01)
   InitBlikanie();                      // (90)
   Premenna.PriznakMinuta  = Nie;       // Priznak minuty ( caka na tik minuty)
   Premenna.PriznakPolnoc  = Ano;       // Priznak polnoci ( Bude reagovat na polnoc)
   Premenna.PriznakOE      = Nie;       // Priznak tlacidla OE (Displej svieti)
   Premenna.PriznakTlacidla= Nie;       // Priznak stlaceneho tlacidla
   Premenna.ZmenaPostfixu  = Nie;       // Priznak ci sa prestavil postfix
   Premenna.ZmenaCasu      = Nie;       // Priznak ci sa prestavil cas
   Premenna.PriznakKoniec  = Nie;       // Priznak konca suboru 
// NastavCas(); // * PRE TESTOVANIE *   // (90)

   Premenna.Chyba = ChybaSD;
   while (Premenna.Chyba == ChybaSD) InitSD();        // (20)
   
   InitEEPROM();                                      // (20)
   
   Premenna.Chyba = ChybaSubor;   
   while (Premenna.Chyba == ChybaSubor) InitSubor();  // (20)
   
   Premenna.Chyba = ChybaOtvor;   
   while (Premenna.Chyba == ChybaOtvor) OtvorSubor(); // (20)
   
   CitajCasDS3231();                                  // (40)
   ZapisCas7segment();                                // (50)
   CitajRiadok();                                     // (20)
   AnalyzujRiadok();                                  // (60)
   Premenna.PriznakKoniec  = Nie;       // Priznak konca suboru 
}

/********************************************************
 * LOOP
 ********************************************************/
 void loop (void) {
   CitajCasDS3231();                    // (40)

   if (!digitalRead(pin_GS)) {          // Ak je tlacidlo stlacene
     Premenna.PriznakTlacidla= Ano;     // Priznak stlaceneho tlacidla
     Tl_Mod();                          // (70)
   }
   
   if (Premenna.PriznakMinuty) {
     ZapisCas7segment();                // (50)
     
     if (SDHodnota.PocetMinut == DisplejCas.PocetMinut) {
       AnalyzujZvonenie();              // (60)
       CitajRiadok();                   // (20)
     }
     Premenna.PriznakMinuty = Nie;
   }
   
// Cas 00:00, resetuj subor
   if ((DisplejCas.PocetMinut == 0) && Premenna.PriznakPolnoc) {
     Serial.println(F("Polnoc"));
     Premenna.PriznakKoniec  = Nie;     // Priznak konca suboru 
     Zaznam.close();
     OtvorSubor();                      // (20)
     CitajRiadok();                     // (20)
     AnalyzujRiadok();                  // (60)
     Premenna.PriznakMinuty = Nie;
     Premenna.PriznakPolnoc = Nie;
   }
   
// Cas 00:01, povol resetovani o polnoci
   if ((DisplejCas.PocetMinut == 1) && (!Premenna.PriznakPolnoc)) {
     Serial.println(F("00:01"));
     Premenna.PriznakPolnoc  = Ano;  
   }
   Blikanie();
 }

 
